.quill-wrapper {
    clear: left;
    margin-left: -12px;
    margin-right: -12px;
}

.ql-container ul {
    margin-left: 2em !important;
    padding-left: 0 !important;
}

.ql-toolbar {
    border-top: 1px solid #eee;
    border-bottom: 1px solid #eee;
}

.close {
    float: right;
    padding: 0;
    border: 0;
    font-size: 18px;
    background: none;
    color: #000;
    line-height: 1;
    opacity: 0.4;
    cursor: pointer;
}

.close:hover {
    opacity: 1;
}

.ql-image-alert {
    padding: 10px;
    margin-bottom: 0;
}

.ql-image-alert-error {
    background: #e74c3c;
    color: white;
}

.ql-image-alert-error .close {
    position: relative;
    top: -2px;
    color: #fff;
}

.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-image.hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAElBMVEUAAAAAZswAZcwAZs0AZs0AZszYB6XUAAAABXRSTlMAeMTFxj7M9NAAAABBSURBVAjXY2DAD1RDQSAYyAqFABALLANmMRnAWMwODIIMUFnGUAEIS1A0NADMYgTqhLBY4SyEKXCTTcGMEAJuAgBa9RKl6Fva+wAAAABJRU5ErkJggg==");
}

.ql-editor {
    min-height: 80px !important;
    max-height: 200px;
    overflow-y: auto;
}

/* Suit Override */
.suit-column .form-horizontal .control-group .quill-wrapper,
.suit-column .form-horizontal .control-group .quill-wrapper {
    margin-top: -6px;
    margin-left: -15px;
    margin-right: -15px;
}

.suit-column .form-horizontal .control-group:first-child .quill-wrapper,
.suit-column .form-horizontal .control-group:first-of-type .quill-wrapper {
    margin-top: -10px;
}

.suit-column .form-horizontal .control-group .ql-toolbar,
.suit-column .form-horizontal .control-group .ql-toolbar {
    border-top: 1px solid #ededed;
    border-bottom: 1px solid #ededed;
}

.suit-column .form-horizontal .control-group:first-child .ql-toolbar,
.suit-column .form-horizontal .control-group:first-of-type .ql-toolbar {
    border-top: 0;
}

.suit-column .ql-editor {
    background: #fff;
    border: 1px solid #ccc;
    border-radius: 4px;
    padding: 4px;
}
